==> 3.5.12-core.tar: kdepim/kaddressbook/kcmconfigs/extensionconfigdialog.h <==
/*
    This file is part of KAddressBook.
    Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef EXTENSIONCONFIGDIALOG_H
#define EXTENSIONCONFIGDIALOG_H

#include <kdialogbase.h>

#include "extensionwidget.h"

namespace KAB {
class ConfigureWidget;
}

class ExtensionConfigDialog : public KDialogBase
{
  Q_OBJECT

  public:
    ExtensionConfigDialog( KAB::ExtensionFactory *factory, KConfig *config,
                           TQWidget *parent, const char *name = 0 );
    ~ExtensionConfigDialog();

  protected slots:
    void slotOk();

  private:
    KAB::ConfigureWidget *mWidget;
    KConfig *mConfig;
};

#endif

==> 3.5.13-core.tar: kdepim/kaddressbook/kcmconfigs/extensionconfigdialog.h <==
/*
    This file is part of KAddressBook.
    Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of TQt, and distribute the resulting executable,
    without including the source code for TQt in the source distribution.
*/

#ifndef EXTENSIONCONFIGDIALOG_H
#define EXTENSIONCONFIGDIALOG_H

#include <kdialogbase.h>

#include "extensionwidget.h"

namespace KAB {
class ConfigureWidget;
}

class ExtensionConfigDialog : public KDialogBase
{
  Q_OBJECT
  TQ_OBJECT

  public:
    ExtensionConfigDialog( KAB::ExtensionFactory *factory, KConfig *config,
                           TQWidget *parent, const char *name = 0 );
    ~ExtensionConfigDialog();

  protected slots:
    void slotOk();

  private:
    KAB::ConfigureWidget *mWidget;
    KConfig *mConfig;
};

#endif
